@@ -81,6 +81,7 @@ class APIClient:
         self.version_param = '2020-08-01'
         self.ICP_PLATFORM_SPACES = False # This will be applicable for 3.5 and later and specific to convergence functionalities
         self.ICP_35 = False # Use it for any 3.5 specific functionalities
+        self.CLOUD_BETA_FLOW = False
         # self.version_param = '2020-06-12'
 
         self.PLATFORM_URLS_MAP = {
@@ -232,6 +233,7 @@ class APIClient:
                                           "client.set.default_space(space_id) is called ")
 
                             if not self.CLOUD_PLATFORM_SPACES:
+                                self.CLOUD_BETA_FLOW = True
                                 print("NOTE!! DEPRECATED!! Creating assets using this flow(v4 beta) is deprecated"
                                       " starting Sep 1st, 2020 and will be discontinued at the end of the migration period. "
                                       "Refer to the documentation at 'https://dataplatform.cloud.ibm.com/docs/content/wsj/analyze-data/wml-ai.html' "
@@ -260,6 +262,7 @@ class APIClient:
                                                  "to be provided here. It will be picked up from space when "
                                                  "client.set.default_space(space_id) is called.\n  Error:" + response_get_instance.text)
 
+                        self.CLOUD_BETA_FLOW = True
                         print("NOTE!! DEPRECATED!! Creating assets using this flow(v4 beta) is deprecated"
                               " starting Sep 1st, 2020 and will be discontinued at the end of the migration period. "
                               "Refer to the documentation at 'https://dataplatform.cloud.ibm.com/docs/content/wsj/analyze-data/wml-ai.html' "
@@ -277,7 +280,11 @@ class APIClient:
         self.project_id = project_id
         self.wml_token = None
 
-       # if not self.ICP and not self.ICP_30 and not self.WSD:
+        if not self.CLOUD_PLATFORM_SPACES and not self.ICP_PLATFORM_SPACES and not self.CLOUD_BETA_FLOW:
+            raise WMLClientError("This client is not supported in this release. Refer to the documentation at "
+                                 "http://ibm-wml-api-pyclient.mybluemix.net to know what releases are supported")
+
+        # if not self.ICP and not self.ICP_30 and not self.WSD:
         if not self.WSD and not self.CLOUD_PLATFORM_SPACES and not self.ICP_PLATFORM_SPACES:
             self.service_instance = ServiceInstance(self)
             self.service_instance.details = self.service_instance.get_details()
