@@ -436,7 +436,7 @@ class Batch(BaseDeployment):
         return self._target_workspace.wml_client.deployments.get_job_status(scoring_job_id)
 
     @BaseDeployment._project_to_space_to_project
-    def get_job_result(self, scoring_job_id: str) -> Union[Dict, 'DataFrame']:
+    def get_job_result(self, scoring_job_id: str) -> 'DataFrame':
         """Get batch deployment results of job with id `scoring_job_id`.
 
         Parameters
@@ -446,47 +446,21 @@ class Batch(BaseDeployment):
 
         Returns
         -------
-        Dictionary with predictions for scoring job with inline input data or
-            dictionary with data reference to output data if the scoring job has reference to input data.
-            In case of incompleted or failed scoring None is returned.
+        DataFrame with result.
+            In case of incompleted or failed `MissingScoringResults` scoring exception is raised.
         """
         scoring_params = self.get_job_params(scoring_job_id)['entity']['scoring']
         if scoring_params['status']['state'] == 'completed':
             if 'predictions' in scoring_params:
-                return scoring_params['predictions']
+                data = DataFrame(scoring_params['predictions'][0]['values'], columns=scoring_params['predictions'][0]['fields'])
+                return data
             else:
-                return self._download_results(scoring_params['output_data_reference'], scoring_job_id)
+                conn = DataConnection._from_dict(scoring_params['output_data_reference'])
+                conn._wml_client = self._target_workspace.wml_client
+                return conn.read() # if in future output may be excel file or with custom separator, here it should be recognized
         else:
             raise MissingScoringResults(scoring_job_id, reason="Scoring is not completed.")
 
-    @staticmethod
-    def _download_results(data_connection: dict, scoring_job_id: str) -> Union[Dict, 'DataFrame']:
-        """Download batch results."""
-
-        if 's3' in str(data_connection):
-            cos_client = init_cos_client(data_connection['connection'])
-
-            # note: fetch all batch results file names per scoring_job_id
-            cos_summary = cos_client.Bucket(data_connection['location']['bucket']).objects.filter(
-                Prefix=data_connection['location']['path'])
-            file_names = [file_name.key for file_name in cos_summary if scoring_job_id in file_name.key]
-            # --- end note
-
-            # TODO: this can be done simultaneously (multithreading / multiprocessing)
-            # note: download all data parts and concatenate them into one output
-            parts = []
-            for file_name in file_names:
-                file = cos_client.Object(data_connection['location']['bucket'], file_name).get()
-                buffer = io.BytesIO(file['Body'].read())
-                parts.append(try_load_dataset(buffer=buffer))
-
-            data = concat(parts)
-            # --- end note
-            return data
-
-        else:
-            return data_connection
-
     @BaseDeployment._project_to_space_to_project
     def get_job_id(self, batch_scoring_details):
         """Get id from batch scoring details."""
