@@ -1,17 +1,29 @@
+# (C) Copyright IBM Corp. 2020.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from typing import TYPE_CHECKING, Any, Dict, Union, List, Optional
-from warnings import warn
-from copy import copy
 
 from pandas import DataFrame
 
 from .base_deployment import BaseDeployment
 from ..wml_client_error import WMLClientError
-from ..workspace import WorkSpace
 
 if TYPE_CHECKING:
     from sklearn.pipeline import Pipeline
     from pandas import DataFrame
     from numpy import ndarray
+    from ..workspace import WorkSpace
 
 __all__ = [
     "WebService"
@@ -55,64 +67,18 @@ class WebService(BaseDeployment):
                  project_id: str = None,
                  space_id: str = None):
 
-        # note: backward compatibility
-        if wml_credentials is not None:
-            source_wml_credentials = wml_credentials
-            warn("\"wml_credentials\" parameter is depreciated, please use \"source_wml_credentials\"")
-            print("\"wml_credentials\" parameter is depreciated, please use \"source_wml_credentials\"")
-
-        if project_id is not None:
-            source_project_id = project_id
-            warn("\"project_id\" parameter is depreciated, please use \"source_project_id\"")
-            print("\"project_id\" parameter is depreciated, please use \"source_project_id\"")
-
-        if space_id is not None:
-            source_space_id = space_id
-            warn("\"space_id\" parameter is depreciated, please use \"source_space_id\"")
-            print("\"space_id\" parameter is depreciated, please use \"source_space_id\"")
-        # --- end note
-
-        # note: as workspace is not clear enough to understand, there is a possibility to use pure
-        # wml credentials with project and space IDs, but in addition we
-        # leave a possibility to use a previous WorkSpace implementation, it could be passed as a first argument
-        super().__init__(deployment_type='online')
-        if isinstance(source_wml_credentials, WorkSpace):
-            self._source_workspace = source_wml_credentials
-
-        elif isinstance(source_wml_credentials, dict):
-            self._source_workspace = WorkSpace(wml_credentials=source_wml_credentials.copy(),
-                                               project_id=source_project_id,
-                                               space_id=source_space_id)
-        else:
-            self._source_workspace = None
-
-        if target_wml_credentials is None:
-            if isinstance(source_wml_credentials, WorkSpace):
-                self._target_workspace = source_wml_credentials
-
-            elif isinstance(source_wml_credentials, dict):
-                self._target_workspace = WorkSpace(wml_credentials=source_wml_credentials.copy(),
-                                                   project_id=source_project_id,
-                                                   space_id=source_space_id)
-            else:
-                self._target_workspace = None
-
-        else:
-            if isinstance(target_wml_credentials, WorkSpace):
-                self._target_workspace = target_wml_credentials
-
-            elif isinstance(target_wml_credentials, dict):
-                self._target_workspace = WorkSpace(wml_credentials=target_wml_credentials.copy(),
-                                                   project_id=target_project_id,
-                                                   space_id=target_space_id)
-
-                # note: only if user provides target WML information
-                if self._source_workspace is None:
-                    self._source_workspace = copy(self._target_workspace)
-
-            else:
-                self._target_workspace = None
-        # --- end note
+        super().__init__(
+            deployment_type='online',
+            source_wml_credentials=source_wml_credentials,
+            source_project_id=source_project_id,
+            source_space_id=source_space_id,
+            target_wml_credentials=target_wml_credentials,
+            target_project_id=target_project_id,
+            target_space_id=target_space_id,
+            wml_credentials=wml_credentials,
+            project_id=project_id,
+            space_id=space_id
+        )
 
         self.name = None
         self.scoring_url = None
@@ -126,7 +92,7 @@ class WebService(BaseDeployment):
         return f"name: {self.name}, id: {self.id}, scoring_url: {self.scoring_url}, asset_id: {self.asset_id}"
 
     def create(self,
-               model: Any,
+               model: str,
                deployment_name: str,
                metadata: Optional[Dict] = None,
                training_data: Optional[Union['DataFrame', 'ndarray']] = None,
@@ -137,8 +103,8 @@ class WebService(BaseDeployment):
 
         Parameters
         ----------
-        model: Union[Any, str], required
-            Model object to deploy or local path to the model.
+        model: str, required
+            AutoAI model name.
 
         deployment_name: str, required
             Name of the deployment
@@ -293,8 +259,6 @@ class WebService(BaseDeployment):
                 pipeline_model: 'Pipeline',
                 deployment_name: str,
                 meta_props: Dict,
-                training_data: Union['DataFrame', 'ndarray'],
-                training_target: Union['DataFrame', 'ndarray'],
                 result_client=None) -> Dict:
         """
         Deploy model into WML.
@@ -307,12 +271,6 @@ class WebService(BaseDeployment):
         deployment_name: str, required
             Name of the deployment
 
-        training_data: Union['pandas.DataFrame', 'numpy.ndarray'], required
-            Training data for the model
-
-        training_target: Union['pandas.DataFrame', 'numpy.ndarray'], required
-            Target/label data for the model
-
         meta_props: dictionary, required
             Model meta properties.
 
@@ -321,9 +279,7 @@ class WebService(BaseDeployment):
         """
         deployment_details = {}
         asset_uid = self._publish_model(pipeline_model=pipeline_model,
-                                        meta_props=meta_props,
-                                        training_data=training_data,
-                                        training_target=training_target)
+                                        meta_props=meta_props)
 
         self.asset_id = asset_uid
 
