@@ -117,6 +117,7 @@ class Deployments(WMLResource):
              """
             #artifact_uid = str_type_conv(artifact_uid) if artifact_uid is not None else (str_type_conv(kwargs['model_uid'] if 'model_uid' in kwargs else None))
             ##To be removed once deployments adds support for projects
+            WMLResource._chk_and_block_create_update_for_python36(self)
             self._client._check_if_space_is_set()
 
             Deployments._validate_type(artifact_uid, u'artifact_uid', STR_TYPE, True)
@@ -976,6 +977,7 @@ class Deployments(WMLResource):
                  >>> deployment_details = client.deployments.update(deployment_uid, changes=metadata)
 
         """
+        WMLResource._chk_and_block_create_update_for_python36(self)
         ##To be removed once deployments adds support for deployments
         self._client._check_if_space_is_set()
 
@@ -1134,6 +1136,7 @@ class Deployments(WMLResource):
 
          """
 
+        WMLResource._chk_and_block_create_update_for_python36(self)
         Deployments._validate_type(deployment_id, u'deployment_uid', STR_TYPE, True)
         Deployments._validate_type(meta_props, u'meta_props', dict, True)
 
@@ -1212,6 +1215,42 @@ class Deployments(WMLResource):
                 payload["decision_optimization"]["input_data"] = score_payload
 
         if self._client.ICP_30 or self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
+            import copy
+            if 'input_data_references' in meta_props:
+                Deployments._validate_type(meta_props.get('input_data_references'), u'input_data_references', list,
+                                           True)
+                modified_input_data_references=False
+                input_data = copy.deepcopy(meta_props.get('input_data_references'))
+                for i, input_data_fields in enumerate(input_data):
+                    if 'connection' not in input_data_fields:
+                        modified_input_data_references=True
+                        input_data_fields.update({'connection': {}})
+                if modified_input_data_references:
+                    if 'scoring' in payload:
+                        payload['scoring'].update({'input_data_references': input_data})
+                    else:
+                        payload['decision_optimization'].update({'input_data_references': input_data})
+
+            if 'output_data_reference' in meta_props:
+                Deployments._validate_type(meta_props.get('output_data_reference'), u'output_data_reference', dict,
+                                           True)
+
+                output_data = copy.deepcopy(meta_props.get('output_data_reference'))
+                if 'connection' not in output_data:  # and output_data.get('connection', None) is not None:
+                    output_data.update({'connection': {}})
+                    payload['scoring'].update({'output_data_reference': output_data})
+
+            if 'output_data_references' in meta_props:
+                Deployments._validate_type(meta_props.get('output_data_references'), u'output_data_references', list, True)
+                output_data = copy.deepcopy(meta_props.get('output_data_references'))
+                modified_output_data_references = False
+                for i, output_data_fields in enumerate(output_data):
+                    if 'connection' not in output_data_fields:
+                        modified_output_data_references = True
+                        output_data_fields.update({'connection': {}})
+                if modified_output_data_references and 'decision_optimization' in payload:
+                    payload['decision_optimization'].update({'output_data_references': output_data})
+
             payload.update({"deployment": {"id": deployment_id}})
             if 'hardware_spec' in meta_props:
                 payload.update({"hardware_spec": meta_props[self.ConfigurationMetaNames.HARDWARE_SPEC]})
