@@ -107,6 +107,8 @@ class AutoAI(BaseExperiment):
             self.space_id = self._workspace.space_id
             self.runs = AutoPipelinesRuns(engine=WMLEngine(self._workspace))
             self.runs._workspace = self._workspace
+
+        self._20_class_limit_removal_test = False
         # --- end note
 
     def runs(self, *, filter: str) -> Union['AutoPipelinesRuns', 'LocalAutoPipelinesRuns']:
@@ -304,6 +306,11 @@ class AutoAI(BaseExperiment):
 
             validate_additional_params_for_optimizer(reduced_kwargs)
 
+            engine = WMLEngine(self._workspace)
+
+            if self._20_class_limit_removal_test:
+                engine._20_class_limit_removal_test = True
+
             optimizer = RemoteAutoPipelines(
                 name=name,
                 prediction_type=prediction_type,
@@ -324,7 +331,7 @@ class AutoAI(BaseExperiment):
                 encoding=encoding,
                 positive_label=positive_label,
                 data_join_only=data_join_only,
-                engine=WMLEngine(self._workspace),
+                engine=engine,
                 notebooks=kwargs.get('notebooks', True),
                 autoai_pod_version=kwargs.get('autoai_pod_version', None),
                 obm_pod_version=kwargs.get('obm_pod_version', None),
