@@ -16,15 +16,19 @@ from typing import TYPE_CHECKING, List, Dict
 
 from pandas import DataFrame, MultiIndex
 import json
+from time import sleep
 
 from ibm_watson_machine_learning.utils.autoai.enums import (
-    PredictionType, RegressionAlgorithms, ClassificationAlgorithms)
-from ibm_watson_machine_learning.utils.autoai.errors import PipelineNotLoaded, FitNeeded, InvalidPredictionType
+    PredictionType, RegressionAlgorithms, ClassificationAlgorithms, RunStateTypes)
+from ibm_watson_machine_learning.utils.autoai.errors import PipelineNotLoaded, FitNeeded, InvalidPredictionType, \
+    AutoAIComputeError
+from ibm_watson_machine_learning.wml_client_error import ApiRequestFailure
 from ibm_watson_machine_learning.utils.autoai.progress_bar import ProgressBar
 from ibm_watson_machine_learning.utils.autoai.utils import (
     fetch_pipelines, is_ipython, ProgressGenerator, check_dependencies_versions, try_import_autoai_libs,
     create_summary, prepare_auto_ai_model_to_publish_normal_scenario, get_sw_spec_and_type_based_on_sklearn)
 from .base_engine import BaseEngine
+from ibm_watson_machine_learning.helpers.connections import DataConnection
 
 if TYPE_CHECKING:
     from ibm_watson_machine_learning.workspace import WorkSpace
@@ -54,6 +58,7 @@ class WMLEngine(BaseEngine):
         self._wml_training_metadata = None
         self._wml_stored_pipeline_details = None
         self._current_run_id = None
+        self._20_class_limit_removal_test = False
 
     def _initialize_wml_pipeline_metadata(self) -> None:
         """
@@ -130,6 +135,11 @@ class WMLEngine(BaseEngine):
             }
         }
 
+        if self._20_class_limit_removal_test:
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT]['pipelines'][0]['nodes'][0]['parameters'].update({
+                'one_vs_all_file': True
+            })
+
         # note: in new v4 api we have missing hw_spec name
         t_size = self._auto_pipelines_parameters['t_shirt_size']
         if 0 < len(t_size) <= 2:
@@ -377,12 +387,10 @@ class WMLEngine(BaseEngine):
             websocket.add_header(bytes("Authorization", "utf-8"),
                                  bytes("Bearer " + self._wml_client.service_instance._get_token(), "utf-8"))
 
-            gen = ProgressGenerator(number_of_estimators)
+            gen = ProgressGenerator()
             end = False
 
-            progress_bar = ProgressBar(desc="Total", total=gen.get_total(), position=0, ncols=100, bar_format=None)
-
-            texts = {}
+            progress_bar = ProgressBar(desc="Total", total=gen.get_total(), position=0, ncols=100, bar_format='{l_bar}{bar}| [{elapsed}<{remaining}, ' '{rate_fmt}{postfix}]')
 
             while not end:
                 progress_bar.set_description(desc='Started waiting for resources')
@@ -393,30 +401,33 @@ class WMLEngine(BaseEngine):
                         pass
                     if event.name == 'text':
                         status = json.loads(event.text)['entity']['status']
-                        if 'message' in status and 'text' in status['message']:
+                        if status.get('state') == RunStateTypes.FAILED:
+                            sleep(3)
+
+                            message = status.get('message', {}).get('text', 'Training failed')
+                            progress_bar.set_description(desc=message)
+
+                            if 'Not Found' in str(message) or 'HeadObject' in str(message):
+                                raise AutoAIComputeError(self._current_run_id,
+                                                         reason=f"Fetching training data error. Please check if COS credentials, "
+                                                                f"bucket name and path are correct or file system path is correct.")
+
+                            elif 'Failed_Image' in str(message):
+                                raise AutoAIComputeError(
+                                    self._current_run_id,
+                                    reason=f"This version of WML V4 SDK with AutoAI component is no longer supported. "
+                                           f"Please update your package to the newest version. "
+                                           f"Error: {message}")
+
+                            else:
+                                raise AutoAIComputeError(self._current_run_id, reason=f"Error: {message}")
+                        elif 'message' in status and 'text' in status['message']:
                             text = status['message']['text']
 
                             try:
-                                phase = status['metrics'][0]['context']['phase']
+                                process = status['metrics'][0]['context']['intermediate_model']['process']
                             except:
-                                phase = ""
-
-                            try:
-                                step_name = status['metrics'][0]['context']['step']['name']
-                            except:
-                                step_name = ""
-
-                            try:
-                                step_estimator = status['metrics'][0]['context']['step']['estimator']
-                            except:
-                                step_estimator = ""
-
-                            log = f"{phase}:{step_name}:{step_estimator}:{text}"
-
-                            if log not in texts:
-                                texts[log] = 1
-                            else:
-                                texts[log] = texts[log] + 1
+                                process = ''
 
                             if self._current_run_id in text and 'completed' in text:
                                 end = True
@@ -433,15 +444,12 @@ class WMLEngine(BaseEngine):
                                 else:
                                     progress_bar.set_description(desc=prepared_text + ' '*(max_len-len(prepared_text)))
 
-                            progress_bar.increment_counter(gen.get_progress(log))
+                            progress_bar.increment_counter(gen.get_progress(process))
                             progress_bar.update()
                     elif event.name in ['closing', 'disconnected']:
                         end = True
                         break
 
-            #for t in texts:
-            #    print(f"{t}: {texts[t]}")
-
             websocket.close()
             return self._wml_client.training.get_details(training_uid=self._current_run_id)
 
@@ -537,16 +545,20 @@ class WMLEngine(BaseEngine):
                             and 'binary_classification' in str(run_params))):
 
                     pipeline_parameters['features_importance'] = self._get_features_importance(pipeline)
-                    pipeline_parameters['confusion_matrix'] = self._get_confusion_matrix(pipeline)
-                    pipeline_parameters['roc_curve'] = self._get_roc_curve(pipeline)
+                    pipeline_parameters['confusion_matrix'] = self._get_confusion_matrix(pipeline, run_params)
+                    pipeline_parameters['roc_curve'] = self._get_roc_curve(pipeline, run_params)
 
                 elif (self._auto_pipelines_parameters['prediction_type'] == 'multiclass'
                       or (self._auto_pipelines_parameters['prediction_type'] == 'classification'
                           and 'multi_class_classification' in str(run_params))):
 
+                    one_vs_all_data = WMLEngine._get_data_from_property_or_file('one_vs_all',
+                                                   pipeline['context'].get('multi_class_classification', {'one_vs_all': []}),
+                                                   run_params['entity']['results_reference'], [{}, {}])
+
                     pipeline_parameters['features_importance'] = self._get_features_importance(pipeline)
-                    pipeline_parameters['roc_curve'] = self._get_one_vs_all(pipeline, 'roc_curve')
-                    pipeline_parameters['confusion_matrix'] = self._get_one_vs_all(pipeline, 'confusion_matrix')
+                    pipeline_parameters['roc_curve'] = self._get_one_vs_all(one_vs_all_data, run_params, 'roc_curve')
+                    pipeline_parameters['confusion_matrix'] = self._get_one_vs_all(one_vs_all_data, run_params, 'confusion_matrix')
 
                 elif self._auto_pipelines_parameters['prediction_type'] == 'regression':
                     pipeline_parameters['features_importance'] = self._get_features_importance(pipeline)
@@ -573,10 +585,23 @@ class WMLEngine(BaseEngine):
         return metrics
 
     @staticmethod
-    def _get_confusion_matrix(pipeline_details: Dict) -> 'DataFrame':
-        """Retrieve confusion matrix data from particular pipeline details. (Binary)"""
-        data = pipeline_details['context'].get('binary_classification',
-                                               {'confusion_matrix': [{}, {}]})['confusion_matrix']
+    def _get_data_from_property_or_file(property_name: str, details: Dict, results_reference: Dict, default_value: List) -> List:
+        if f'{property_name}_location' in details:
+            path = details[f'{property_name}_location']
+            conn = DataConnection._from_dict(results_reference)
+            return conn._download_json_file(path)
+        elif property_name in details:  # TODO probably should be removed in future
+            return details[property_name]
+        else:
+            return default_value
+
+    @staticmethod
+    def _get_confusion_matrix(pipeline_details: Dict, run_params: Dict) -> 'DataFrame':
+        """Retrieve confusion matrix data from particular pipeline details or from file. (Binary)"""
+        data = WMLEngine._get_data_from_property_or_file('confusion_matrix',
+                                                         pipeline_details['context'].get('binary_classification', {}),
+                                                         run_params['entity']['results_reference'],
+                                                         [{}, {}])
         columns = [name for name in data[0].keys()]
         values = [[value for value in item.values()] for item in data]
 
@@ -600,9 +625,13 @@ class WMLEngine(BaseEngine):
         return features_importance_data
 
     @staticmethod
-    def _get_roc_curve(pipeline_details: Dict) -> 'DataFrame':
-        """Retrieve roc curve data from particular pipeline details. (Binary)"""
-        data = pipeline_details['context'].get('binary_classification', {'roc_curve': []})['roc_curve']
+    def _get_roc_curve(pipeline_details: Dict, run_params: Dict) -> 'DataFrame':
+        """Retrieve roc curve data from particular pipeline details or from file. (Binary)"""
+        data = WMLEngine._get_data_from_property_or_file('roc_curve',
+                                                         pipeline_details['context'].get('binary_classification', {}),
+                                                         run_params['entity']['results_reference'],
+                                                         [])
+
         true_classes = [item['true_class'] for item in data]
         values = [data[0]['fpr'], data[1]['fpr'], data[0]['thresholds'], data[1]['thresholds'], data[0]['tpr'],
                   data[1]['tpr']]
@@ -615,23 +644,28 @@ class WMLEngine(BaseEngine):
         return roc_curve
 
     @staticmethod
-    def _get_one_vs_all(pipeline_details: Dict, option: str) -> 'DataFrame':
+    def _get_one_vs_all(one_vs_all_data: List, run_params: Dict, option: str) -> 'DataFrame':
         """Retrieve roc curve or confusion matrix data from particular pipeline details. (Multiclass)"""
-        data = pipeline_details['context'].get('multi_class_classification', {'one_vs_all': []})['one_vs_all']
-
         if option == 'confusion_matrix':
-            confusion_matrix_values = [item['confusion_matrix'].values() for item in data]
+            confusion_matrix_data = [WMLEngine._get_data_from_property_or_file('confusion_matrix', item,
+                                     run_params['entity']['results_reference'], [{}, {}]) for item in one_vs_all_data]
+
+            columns = ['fn', 'fp', 'tn', 'tp', 'true_class']
+            confusion_matrix_values = [[item[c] for c in columns] for item in confusion_matrix_data]
             confusion_matrix_data = DataFrame(data=confusion_matrix_values,
-                                              columns=['fn', 'fp', 'tn', 'tp', 'true_class'])
+                                              columns=columns)
             confusion_matrix_data.index = confusion_matrix_data['true_class']
             confusion_matrix_data.drop(['true_class'], axis=1, inplace=True)
 
             return confusion_matrix_data
 
         elif option == 'roc_curve':
-            true_classes = [item['roc_curve']['true_class'] for item in data]
-            values = [item['roc_curve']['fpr'] for item in data] + [item['roc_curve']['thresholds'] for item in
-                                                                    data] + [item['roc_curve']['tpr'] for item in data]
+            roc_curve_data = [WMLEngine._get_data_from_property_or_file('roc_curve', item,
+                              run_params['entity']['results_reference'], []) for item in one_vs_all_data]
+
+            true_classes = [item['true_class'] for item in roc_curve_data]
+            values = [item['fpr'] for item in roc_curve_data] + [item['thresholds'] for item in
+                                                                    roc_curve_data] + [item['tpr'] for item in roc_curve_data]
             index = MultiIndex.from_product([['fpr', 'thresholds', 'tpr'], true_classes],
                                             names=['measurement types', 'true_class'])
             roc_curve = DataFrame(data=values, index=index)
