@@ -37,7 +37,7 @@ from .base_auto_pipelines import BaseAutoPipelines
 
 if TYPE_CHECKING:
     from ibm_watson_machine_learning.utils.autoai.enums import (
-        Metrics, ClassificationAlgorithms, RegressionAlgorithms)
+        Metrics, ClassificationAlgorithms, RegressionAlgorithms, Transformers)
     from ibm_watson_machine_learning.helpers import DataConnection
     from sklearn.pipeline import Pipeline
     from ibm_boto3 import resource
@@ -84,6 +84,10 @@ class LocalAutoPipelines(BaseAutoPipelines):
     daub_include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']], optional
         List of estimators to include in computation process.
 
+    cognito_transform_names: List['Transformers'], optional
+        List of transformers to include in feature enginnering computation process.
+        See: AutoAI.Transformers
+
     _data_clients: List[Union['client', 'resource']], optional
         Internal argument to auto-gen notebooks.
 
@@ -104,14 +108,17 @@ class LocalAutoPipelines(BaseAutoPipelines):
                  max_num_daub_ensembles: int = 1,
                  train_sample_rows_test_size: float = 1.,
                  daub_include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']] = None,
+                 cognito_transform_names: List['Transformers'] = None,
                  positive_label: str = None,
                  _data_clients: List[Tuple['DataConnection', 'resource']] = None,
                  _result_client: Tuple['DataConnection', 'resource'] = None,
-                 _force_local_scenario: bool = False):
+                 _force_local_scenario: bool = False,
+                 **_additional_params):
 
         self._force_local_scenario = _force_local_scenario
         self._training_data_reference = None
         self._training_result_reference = None
+        self._additional_params = _additional_params
 
         # note: Local scenario should be implemented in the future (ai4ml needed locally)
         if _data_clients is None and _result_client is None:
@@ -150,6 +157,7 @@ class LocalAutoPipelines(BaseAutoPipelines):
                 'max_num_daub_ensembles': int(max_num_daub_ensembles),
                 'train_sample_rows_test_size': train_sample_rows_test_size,
                 'daub_include_only_estimators': daub_include_only_estimators,
+                'cognito_transform_names': cognito_transform_names,
                 'positive_label': positive_label
             }
             self.best_pipeline = None
@@ -662,7 +670,8 @@ class LocalAutoPipelines(BaseAutoPipelines):
             'compute_feature_importances_options': ['pipeline'],
             'compute_pipeline_notebooks_flag': False,
             'max_num_daub_ensembles': self.params['max_num_daub_ensembles'],
-            'scorer_for_ranking': self.params['scoring']
+            'scorer_for_ranking': self.params['scoring'],
+            'cognito_transform_names': self.params.get('cognito_transform_names')
         }
 
         # note: only pass positive label when scoring is binary
@@ -683,7 +692,7 @@ class LocalAutoPipelines(BaseAutoPipelines):
                 self.logger.error(f"Fail setting CPUs ({e}) {traceback.format_exc()}")
         # --- end note
 
-        pdcoe = PrepDaubCogOptEstimator(**estimator_parameters)
+        pdcoe = PrepDaubCogOptEstimator(**estimator_parameters, **self._additional_params)
         self.logger.debug(f"{train_id} --- Training started at: {strftime(DATE_FORMAT, gmtime())}")
 
         # Disable printing to suppress warnings from ai4ml
