@@ -26,7 +26,7 @@ from ibm_watson_machine_learning.utils.autoai.enums import (
     RunStateTypes, PipelineTypes, TShirtSize, ClassificationAlgorithms, RegressionAlgorithms, DataConnectionTypes)
 from ibm_watson_machine_learning.utils.autoai.errors import (
     FitNotCompleted, MissingDataPreprocessingStep, WrongDataJoinGraphNodeName, DataSourceSizeNotSupported,
-    TrainingDataSourceIsNotFile, NoneDataConnection, PipelineNotLoaded)
+    TrainingDataSourceIsNotFile, NoneDataConnection, PipelineNotLoaded, OBMForNFSIsNotSupported)
 from ibm_watson_machine_learning.utils.autoai.utils import try_import_lale
 from ibm_watson_machine_learning.utils.autoai.wsd_ui import (
     save_computed_pipelines_for_ui, save_experiment_for_ui, save_metadata_for_ui)
@@ -281,6 +281,9 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         # note: check if DataJoinGraph node names are correct and equivalent
         # to training DataConnections IDs/data_join_node_names
         if self.params['data_join_graph']:
+            if any(filter(lambda x: x.type == DataConnectionTypes.CA, training_data_reference)):
+                raise OBMForNFSIsNotSupported()
+
             data_join_graph = self.params['data_join_graph']
             data_connection_ids = [connection.id for connection in training_data_reference]
             for node_name in [node.table.name for node in data_join_graph.nodes]:
