@@ -101,7 +101,7 @@ class ServiceInstanceNewPlan:
 
     def get_username(self):
         """
-             Get username for your Watson Machine Learning service. Applicable only for Cloud Pak for Data
+             Get username for your Watson Machine Learning service. Applicable only for IBM Cloud Pak® for Data
 
              **Output**
 
@@ -121,7 +121,7 @@ class ServiceInstanceNewPlan:
 
     def get_password(self):
         """
-             Get password for your Watson Machine Learning service. Applicable only for Cloud Pak for Data
+             Get password for your Watson Machine Learning service. Applicable only for IBM Cloud Pak® for Data
 
              **Output**
 
