@@ -58,14 +58,14 @@ class ModelAdapter(object):
         self.model_metadata = model_output.metadata
 
     def artifact(self):
-        if re.match('mllib', self.model_type) is not None:
+        if re.match('mllib', self.model_type) is not None or 'mllib' in self.model_type:
             lib_checker.check_lib(PYSPARK)
             model_artifact_builder = type(
                 "ModelArtifact",
                 (SparkPipelineModelContentLoader, SparkPipelineModelLoader, ModelArtifact, object),
                 {}
             )
-        elif re.match('wml_1.', self.model_type) is not None:
+        elif re.match('wml_1.', self.model_type) is not None or 'wml_1.' in self.model_type:
             lib_checker.check_lib(PYSPARK)
             lib_checker.check_lib(MLPIPELINE)
             model_artifact_builder = type(
@@ -73,14 +73,14 @@ class ModelAdapter(object):
                 (MLPipelineModelContentLoader, SparkPipelineModelLoader, ModelArtifact, object),
                 {}
             )
-        elif re.match('scikit-learn', self.model_type) is not None:
+        elif re.match('scikit-learn', self.model_type) is not None or 'scikit-learn' in self.model_type:
             lib_checker.check_lib(SCIKIT)
             model_artifact_builder = type(
                 "ScikitModelArtifact",
                 (ScikitPipelineModelContentLoader, ScikitPipelineModelLoader, ScikitModelArtifact, object),
                 {}
             )
-        elif re.match('tensorflow', self.model_type) is not None:
+        elif re.match('tensorflow', self.model_type) is not None or 'tensorflow' in self.model_type:
             lib_checker.check_lib(TENSORFLOW)
             model_artifact_builder = type(
                 "TensorflowModelArtifact",
@@ -88,7 +88,7 @@ class ModelAdapter(object):
                 {}
             )
 
-        elif re.match('xgboost', self.model_type) is not None:
+        elif re.match('xgboost', self.model_type) is not None or 'xgboost' in self.model_type:
             lib_checker.check_lib(SCIKIT)
             lib_checker.check_lib(XGBOOST)
             model_artifact_builder = type(
@@ -97,7 +97,8 @@ class ModelAdapter(object):
                 {}
             )
         elif re.match('hybrid', self.model_type) is not None or \
-             re.match('wml-hybrid', self.model_type) is not None:
+             re.match('wml-hybrid', self.model_type) is not None or \
+             'hybrid' in  self.model_type or 'wml-hybrid' in self.model_type:
             model_artifact_builder = type(
                 "HybridModelArtifact",
                 (HybridPipelineModelLoader, HybridPipelineModelArtifact,object),
@@ -110,7 +111,10 @@ class ModelAdapter(object):
                 {}
             )
         else:
-            raise ValueError('Invalid model_type: {}'.format(self.model_type.get('name')))
+            try:
+                raise ValueError('Invalid model_type: {}'.format(self.model_type.get('name')))
+            except:
+                raise ValueError('Invalid model_type: {}'.format(self.model_type))
 
         prop_map = {
             MetaNames.TYPE: self.model_type
@@ -167,7 +171,7 @@ class ModelAdapter(object):
                 prop_map[MetaNames.SPACE_ID] = self.model_metadata.space_id
 
             if self.model_metadata.project_id is not None:
-                prop_map[MetaNames.PROJECT_UID] = self.model_metadata.project_id
+                prop_map[MetaNames.PROJECT_ID] = self.model_metadata.project_id
 
             if self.model_entity.get('hyper_parameters') is not None:
                 prop_map.add(MetaNames.HYPER_PARAMETERS, self.model_entity['hyper_parameters'])
