@@ -26,7 +26,7 @@ _DEFAULT_LIST_LENGTH = 50
 
 class Spaces(WMLResource):
     """
-    Store and manage your spaces. This is applicable only for IBM Cloud Pak™ for Data
+    Store and manage your spaces. This is applicable only for IBM Cloud Pak® for Data for Data
     """
     ConfigurationMetaNames = SpacesMetaNames()
     MemberMetaNames = MemberMetaNames()
@@ -71,6 +71,7 @@ class Spaces(WMLResource):
 
         # quick support for COS credentials instead of local path
         # TODO add error handling and cleaning (remove the file)
+        WMLResource._chk_and_block_create_update_for_python36(self)
         Spaces._validate_type(meta_props, u'meta_props', dict, True)
         space_meta = self.ConfigurationMetaNames._generate_resource_metadata(
             meta_props,
