@@ -37,7 +37,7 @@ class TestPkgExtn(unittest.TestCase):
         print(self.client.spaces.get_details(TestPkgExtn.space_id))
         time.sleep(20)
         print(self.client.spaces.get_details(TestPkgExtn.space_id))
-
+        self.client.set.default_space(TestPkgExtn.space_id)
 
 
     def test_00_create_pkg_extn(self):
@@ -95,7 +95,8 @@ class TestPkgExtn(unittest.TestCase):
     def test_03_create_sw_spec(self):
 
         self.client.software_specifications.ConfigurationMetaNames.show()
-        base_sw_spec_id = self.client.software_specifications.get_id_by_name("ai-function_0.1-py3.6")
+        # base_sw_spec_id = self.client.software_specifications.get_id_by_name("ai-function_0.1-py3.6")
+        base_sw_spec_id = self.client.software_specifications.get_id_by_name("default_py3.7")
 
         meta_prop_sw_spec = {
             self.client.software_specifications.ConfigurationMetaNames.NAME: "sw_spec test" + str(uuid.uuid4()),
@@ -123,6 +124,10 @@ class TestPkgExtn(unittest.TestCase):
         self.client.software_specifications.add_package_extension(TestPkgExtn.sw_spec_id,
                                                                   TestPkgExtn.pkg_extn_id)
 
+        ss_asset_details = self.client.software_specifications.get_details(TestPkgExtn.sw_spec_id)
+        print('Package extensions',
+              print(ss_asset_details['entity']['software_specification']['package_extensions']))
+
     def test_05_get_details(self):
 
         details = self.client.software_specifications.get_details(TestPkgExtn.sw_spec_id)
