@@ -40,14 +40,15 @@ class TestScripts(unittest.TestCase):
 
         self.client.software_specifications.list()
 
-        sw_spec_uid = '0cdb0f1e-5376-4f4d-92dd-da3b69aa9bda'
-        print(self.client.software_specifications.get_details(sw_spec_uid))
-        print("sw_spec_uid: ", sw_spec_uid)
+        # sw_spec_uid = '0cdb0f1e-5376-4f4d-92dd-da3b69aa9bda'
+        sw_spec_id = self.client.software_specifications.get_uid_by_name('default_py3.7')
+        print(self.client.software_specifications.get_details(sw_spec_id))
+        print("sw_spec_uid: ", sw_spec_id)
 
         meta_prop_script = {
             self.client.script.ConfigurationMetaNames.NAME: "my script asset",
             self.client.script.ConfigurationMetaNames.DESCRIPTION: "script asset for deployment",
-            self.client.script.ConfigurationMetaNames.SOFTWARE_SPEC_UID: sw_spec_uid
+            self.client.script.ConfigurationMetaNames.SOFTWARE_SPEC_UID: sw_spec_id
         }
 
         script_details = self.client.script.store(meta_prop_script, file_path="artifacts/test.py")
