@@ -39,7 +39,7 @@ class TestWMLClientWithHybrid(unittest.TestCase):
             }
         }
 
-        self.space = self.client.spaces.store(meta_props=metadata)
+        self.space = self.client.spaces.store(meta_props=metadata, background_mode=False)
 
         TestWMLClientWithHybrid.space_id = self.client.spaces.get_id(self.space)
         print("space_id: ", TestWMLClientWithHybrid.space_id)
