@@ -52,7 +52,7 @@ class TestWMLClientWithSpark(unittest.TestCase):
             }
         }
 
-        self.space = self.client.spaces.store(meta_props=metadata)
+        self.space = self.client.spaces.store(meta_props=metadata, background_mode=False)
 
         print(self.space)
 
