@@ -29,7 +29,8 @@ class TestRemoteTrainingSystems(unittest.TestCase):
                      }
         }
 
-        self.space = self.client.spaces.store(meta_props=metadata)
+        self.space = self.client.spaces.store(meta_props=metadata, background_mode=False)
+        self.space = self.client.spaces.store(meta_props=metadata,  background_mode=False)
 
         TestRemoteTrainingSystems.space_id = self.client.spaces.get_id(self.space)
         print("space_id: ", TestRemoteTrainingSystems.space_id)
