@@ -34,7 +34,7 @@ class TestScripts(unittest.TestCase):
                      }
         }
 
-        self.space = self.client.spaces.store(meta_props=metadata)
+        self.space = self.client.spaces.store(meta_props=metadata, background_mode=False)
 
         TestScripts.space_id = self.client.spaces.get_id(self.space)
         print("space_id: ", TestScripts.space_id)
@@ -45,13 +45,14 @@ class TestScripts(unittest.TestCase):
         self.client.script.ConfigurationMetaNames.show()
         # sw_spec_uid = self.client.software_specifications.get_uid_by_name("ai-function_0.1-py3.6")
 
-        sw_spec_uid = '0cdb0f1e-5376-4f4d-92dd-da3b69aa9bda'
-        print("sw_spec_uid: ", sw_spec_uid)
+        # sw_spec_uid = '0cdb0f1e-5376-4f4d-92dd-da3b69aa9bda'
+        swspec_id = self.client.software_specifications.get_uid_by_name('default_py3.7')
+        print("sw_spec_uid: ", swspec_id)
 
         meta_prop_script = {
             self.client.script.ConfigurationMetaNames.NAME: "my script asset",
             self.client.script.ConfigurationMetaNames.DESCRIPTION: "script asset for deployment",
-            self.client.script.ConfigurationMetaNames.SOFTWARE_SPEC_UID: sw_spec_uid
+            self.client.script.ConfigurationMetaNames.SOFTWARE_SPEC_UID: swspec_id
         }
 
         script_details = self.client.script.store(meta_prop_script, file_path="artifacts/test.py")
