@@ -110,7 +110,7 @@ class TestAutoAIRemote(unittest.TestCase):
         space_cleanup(self.wml_client,
                       get_space_id(self.wml_client, self.space_name,
                                    cos_resource_instance_id=self.cos_resource_instance_id),
-                      days_old=2)
+                      days_old=7)
         TestAutoAIRemote.space_id = get_space_id(self.wml_client, self.space_name,
                                      cos_resource_instance_id=self.cos_resource_instance_id)
 
@@ -412,7 +412,7 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_25_delete_deployment(self):
         print("Delete current deployment: {}".format(self.service.deployment_id))
         self.service.delete()
-        self.wml_client.set.default_space(self.space_id) if is_cp4d() else None
+        self.wml_client.set.default_space(self.space_id) if not self.wml_client.default_space_id else None
         self.wml_client.repository.delete(self.service.asset_id)
         self.wml_client.set.default_project(self.project_id) if is_cp4d() else None
 
