@@ -116,7 +116,7 @@ class TestAutoAIRemote(unittest.TestCase):
         space_cleanup(self.wml_client,
                       get_space_id(self.wml_client, self.space_name,
                                    cos_resource_instance_id=self.cos_resource_instance_id),
-                      days_old=2)
+                      days_old=7)
         TestAutoAIRemote.space_id = get_space_id(self.wml_client, self.space_name,
                                      cos_resource_instance_id=self.cos_resource_instance_id)
         if self.wml_client.ICP:
@@ -333,7 +333,7 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_24_delete_deployment(self):
         print("Delete current deployment: {}".format(self.service.deployment_id))
         self.service.delete()
-        self.wml_client.set.default_space(self.space_id) if is_cp4d() else None
+        self.wml_client.set.default_space(self.space_id) if not self.wml_client.default_space_id else None
         self.wml_client.repository.delete(self.service.asset_id)
         self.wml_client.set.default_project(self.project_id) if is_cp4d() else None
 
@@ -430,7 +430,7 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_35_delete_deployment_batch(self):
         print("Delete current deployment: {}".format(self.service_batch.deployment_id))
         self.service_batch.delete()
-        self.wml_client.set.default_space(self.space_id) if is_cp4d() else None
+        self.wml_client.set.default_space(self.space_id) if not self.wml_client.default_space_id else None
         self.wml_client.repository.delete(self.service_batch.asset_id)
         self.wml_client.set.default_project(self.project_id) if is_cp4d() else None
         self.assertEqual(self.service_batch.id, None, msg="Deployment ID deleted incorrectly")
