@@ -16,7 +16,7 @@ from ibm_watson_machine_learning.workspace import WorkSpace
 from ibm_watson_machine_learning.utils.autoai.enums import TShirtSize
 from ibm_watson_machine_learning.utils.autoai.errors import AutoAIComputeError
 
-from ibm_watson_machine_learning.tests.utils import get_wml_credentials, get_cos_credentials, is_cp4d, bucket_exists,\
+from ibm_watson_machine_learning.tests.utils import get_wml_credentials, get_cos_credentials,  bucket_exists,\
    bucket_name_gen, get_space_id
 from ibm_watson_machine_learning.tests.utils.cleanup import delete_model_deployment, bucket_cleanup, space_cleanup
 
@@ -111,7 +111,7 @@ class TestAutoAIRemote(unittest.TestCase):
         space_cleanup(self.wml_client,
                       get_space_id(self.wml_client, self.space_name,
                                    cos_resource_instance_id=self.cos_resource_instance_id),
-                      days_old=2)
+                      days_old=7)
         TestAutoAIRemote.space_id = get_space_id(self.wml_client, self.space_name,
                                                  cos_resource_instance_id=self.cos_resource_instance_id)
 
@@ -313,7 +313,7 @@ class TestAutoAIRemote(unittest.TestCase):
     #################################
 
     def test_15_list_historical_runs_and_get_run_ids(self):
-        runs_df = self.experiment.runs.list()
+        runs_df = self.experiment.runs(filter=self.OPTIMIZER_NAME).list()
         print(runs_df)
         self.assertIsNotNone(runs_df)
         self.assertGreater(len(runs_df), 0)
@@ -322,7 +322,7 @@ class TestAutoAIRemote(unittest.TestCase):
 
         from random import randint
         TestAutoAIRemote.random_run_id = runs_completed_df.run_id.iloc[
-            randint(len(runs_completed_df) // 2, len(runs_completed_df) - 1)]  # random run_id from the 2nd part of runs table
+            randint(1, min(5, len(runs_completed_df)))]  # random run_id first 5 rows
         print("Random run_id from 2nd half of df: {}".format(TestAutoAIRemote.random_run_id))
         self.assertIsNotNone(TestAutoAIRemote.random_run_id)
 
@@ -349,7 +349,7 @@ class TestAutoAIRemote(unittest.TestCase):
         self.assertGreater(len(predictions), 0, msg="Empty predictions")
 
     def test_18_get_random_historical_optimizer_and_its_pipeline(self):
-        run_params = self.experiment.runs.get_params(run_id=self.random_run_id)
+        run_params = self.experiment.runs(filter=self.OPTIMIZER_NAME).get_params(run_id=self.random_run_id)
         self.assertIn('prediction_type', run_params,
                       msg="prediction_type field not fount in run_params. Run_params are: {}".format(run_params))\
 
@@ -409,7 +409,7 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_24_delete_deployment(self):
         print("Delete current deployment: {}".format(self.service.deployment_id))
         self.service.delete()
-        self.wml_client.set.default_space(self.space_id)
+        self.wml_client.set.default_space(self.space_id) if not self.wml_client.default_space_id else None
         self.wml_client.repository.delete(self.service.asset_id)
         self.wml_client.set.default_project(self.project_id)
 
@@ -449,7 +449,7 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_29_delete_deployment_different_wml(self):
         print("Delete current deployment: {}".format(self.service.deployment_id))
         self.service.delete()
-        self.wml_client.set.default_space(self.space_id)
+        self.wml_client.set.default_space(self.space_id) if not self.wml_client.default_space_id else None
         self.wml_client.repository.delete(self.service.asset_id)
         self.wml_client.set.default_project(self.project_id)
 
@@ -495,7 +495,7 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_35_delete_deployment_batch(self):
         print("Delete current deployment: {}".format(self.service_batch.deployment_id))
         self.service_batch.delete()
-        self.wml_client.set.default_space(self.space_id)
+        self.wml_client.set.default_space(self.space_id) if not self.wml_client.default_space_id else None
         self.wml_client.repository.delete(self.service_batch.asset_id)
         self.wml_client.set.default_project(self.project_id)
         self.assertEqual(self.service_batch.id, None, msg="Deployment ID deleted incorrectly")
