@@ -12,7 +12,7 @@ from ibm_watson_machine_learning.workspace import WorkSpace
 from ibm_watson_machine_learning.utils.autoai.enums import TShirtSize
 from ibm_watson_machine_learning.utils.autoai.errors import AutoAIComputeError
 
-from ibm_watson_machine_learning.tests.utils import get_wml_credentials, is_cp4d, get_space_id
+from ibm_watson_machine_learning.tests.utils import get_wml_credentials, is_cp4d, get_space_id, setup_nfs_env
 from ibm_watson_machine_learning.tests.utils.cleanup import delete_model_deployment, space_cleanup
 
 
@@ -54,6 +54,8 @@ class TestAutoAIRemote(unittest.TestCase):
     data_connection = None
     results_connection = None
 
+    dataset_name = 'iris_dataset.csv'
+    data_location = None
     custom_separator = ','
 
     OPTIMIZER_NAME = 'Iris wml_autoai multiclass test'
@@ -64,7 +66,7 @@ class TestAutoAIRemote(unittest.TestCase):
 
     space_name = 'tests_sdk_space'
 
-    asset_id = 'e5ae313d-4d4c-491e-a9c3-57e180900879'
+    asset_id = '3c1a2156-e816-4f4a-8ea3-4e823f16eb2d'
 
     @classmethod
     def setUpClass(cls) -> None:
@@ -75,11 +77,12 @@ class TestAutoAIRemote(unittest.TestCase):
         cls.wml_credentials = get_wml_credentials()
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials.copy())
         cls.project_id = cls.wml_credentials.get('project_id')
+        #cls.connection_id, cls.data_location, _ = setup_nfs_env(cls.wml_credentials, cls.dataset_name)
 
     def test_00a_space_cleanup(self):
         space_cleanup(self.wml_client,
                       get_space_id(self.wml_client, self.space_name),
-                      days_old=2)
+                      days_old=7)
         TestAutoAIRemote.space_id = get_space_id(self.wml_client, self.space_name)
 
         self.wml_client.set.default_project(self.project_id)
