@@ -38,7 +38,7 @@ get_extractor_columns = OBMPipelineGraphBuilder.get_extractor_columns
 get_extractor_transformations = OBMPipelineGraphBuilder.get_extractor_transformations
 
 
-@unittest.skipIf(is_cp4d, "Excel files and delimiters not yet supported on CPD")
+@unittest.skipIf(is_cp4d(), "Excel files and delimiters not yet supported on CPD")
 class TestOBMAndKB(unittest.TestCase):
     data_join_graph: 'DataJoinGraph' = None
     wml_client: 'APIClient' = None
@@ -67,7 +67,6 @@ class TestOBMAndKB(unittest.TestCase):
     prediction_column = 'temp>=31'
 
     train_data = None
-    holdout_data = None
 
     bucket_name = environ.get('BUCKET_NAME', "wml-autoaitests-obm-qa")
     pod_version = environ.get('KB_VERSION', None)
@@ -132,7 +131,7 @@ class TestOBMAndKB(unittest.TestCase):
         space_cleanup(self.wml_client,
                       get_space_id(self.wml_client, self.space_name,
                                    cos_resource_instance_id=self.cos_resource_instance_id),
-                      days_old=2)
+                      days_old=7)
         TestOBMAndKB.space_id = get_space_id(self.wml_client, self.space_name,
                                      cos_resource_instance_id=self.cos_resource_instance_id)
 
@@ -260,10 +259,10 @@ class TestOBMAndKB(unittest.TestCase):
 
         print(f"data_join_graph: {data_join_graph}")
 
-    @print_test_separators
-    def test_03_data_join_graph_visualization(self):
-        print("Visualizing data_join_graph...")
-        self.data_join_graph.visualize()
+    # @print_test_separators
+    # def test_03_data_join_graph_visualization(self):
+    #     print("Visualizing data_join_graph...")
+    #     self.data_join_graph.visualize()
 
     @print_test_separators
     def test_04_initialize_AutoAI_experiment__pass_credentials__object_initialized(self):
@@ -404,7 +403,7 @@ class TestOBMAndKB(unittest.TestCase):
 
     @print_test_separators
     def test_10_download_preprocessed_obm_training_data(self):
-        print("Downloading OBM preprocessed training data with holdout split...")
+        print("Downloading OBM preprocessed training data ...")
         TestOBMAndKB.train_data = (
             self.remote_auto_pipelines.get_preprocessed_data_connection().read())
 
@@ -414,13 +413,13 @@ class TestOBMAndKB(unittest.TestCase):
         self.assertGreater(len(self.train_data), 0)
 
 
-    @print_test_separators
-    def test_11_visualize_obm_pipeline(self):
-        print("Visualizing OBM model ...")
-        TestOBMAndKB.data_join_pipeline = self.remote_auto_pipelines.get_preprocessing_pipeline()
-        assert isinstance(self.data_join_pipeline._pipeline_json, list)
-        assert '40 [label=NumberSet]' in self.data_join_pipeline._graph.__str__()
-    #     self.data_join_pipeline.visualize()
+    # @print_test_separators
+    # def test_11_visualize_obm_pipeline(self):
+    #     print("Visualizing OBM model ...")
+    #     TestOBMAndKB.data_join_pipeline = self.remote_auto_pipelines.get_preprocessing_pipeline()
+    #     assert isinstance(self.data_join_pipeline._pipeline_json, list)
+    #     assert '40 [label=NumberSet]' in self.data_join_pipeline._graph.__str__()
+    # #     self.data_join_pipeline.visualize()
 
     @print_test_separators
     def test_11b_check_if_data_join_pipeline_graph_correct(self):
@@ -479,7 +478,7 @@ class TestOBMAndKB(unittest.TestCase):
     @print_test_separators
     def test_14_predict_using_fitted_pipeline(self):
         print("Make predictions on best pipeline...")
-        predictions = self.remote_auto_pipelines.predict(X=self.holdout_data.drop([self.prediction_column], axis=1).values[:5])
+        predictions = self.remote_auto_pipelines.predict(X=self.train_data.drop([self.prediction_column], axis=1).values[:5])
         print(predictions)
         self.assertGreater(len(predictions), 0)
 
@@ -534,7 +533,7 @@ class TestOBMAndKB(unittest.TestCase):
             try:
                 lale_pipeline = self.remote_auto_pipelines.get_pipeline(pipeline_name=pipeline_name)
                 self.assertIsInstance(lale_pipeline, TrainablePipeline)
-                predictions = lale_pipeline.predict(X=self.holdout_data.drop([self.prediction_column], axis=1).values[:1])
+                predictions = lale_pipeline.predict(X=self.train_data.drop([self.prediction_column], axis=1).values[:1])
                 print(predictions)
                 self.assertGreater(len(predictions), 0, msg=f"Returned prediction for {pipeline_name} are empty")
             except:
@@ -573,8 +572,8 @@ class TestOBMAndKB(unittest.TestCase):
         print("Do a hyperparameters optimization...")
         hyperopt = Hyperopt(estimator=TestOBMAndKB.new_pipeline, cv=3, max_evals=2)
         try:
-            TestOBMAndKB.hyperopt_pipelines = hyperopt.fit(self.holdout_data.drop([self.prediction_column], axis=1).values,
-                                                           self.holdout_data[self.prediction_column].values)
+            TestOBMAndKB.hyperopt_pipelines = hyperopt.fit(self.train_data.drop([self.prediction_column], axis=1).values,
+                                                           self.train_data[self.prediction_column].values)
         except ValueError as e:
             print(f"ValueError message: {e}")
             traceback.print_exc()
@@ -597,7 +596,7 @@ class TestOBMAndKB(unittest.TestCase):
     def test_21_predict_refined_pipeline(self):
         print("Make predictions on locally optimized pipeline...")
         predictions = TestOBMAndKB.new_sklearn_pipeline.predict(
-            X=self.holdout_data.drop([self.prediction_column], axis=1).values[:1])
+            X=self.train_data.drop([self.prediction_column], axis=1).values[:1])
         print(predictions)
         self.assertGreater(len(predictions), 0, msg=f"Returned prediction for refined pipeline are empty")
 
@@ -614,7 +613,7 @@ class TestOBMAndKB(unittest.TestCase):
     @print_test_separators
     def test_23_predict__do_the_predict_on_sklearn_pipeline__results_computed(self):
         print("Make predictions on sklearn pipeline...")
-        predictions = self.pipeline.predict(self.holdout_data.drop([self.prediction_column], axis=1).values)
+        predictions = self.pipeline.predict(self.train_data.drop([self.prediction_column], axis=1).values)
         print(predictions)
 
 
@@ -631,15 +630,12 @@ class TestOBMAndKB(unittest.TestCase):
     @print_test_separators
     def test_25_get_obm_training_data_from_historical_optimizer(self):
         print("Download historical preprocessed data from OBM stage...")
-        train_data, holdout_data = (
-            self.historical_opt.get_preprocessed_data_connection().read(with_holdout_split=True))
+        train_data = (
+            self.historical_opt.get_preprocessed_data_connection().read())
 
         print("OBM train data sample:")
         print(train_data.head())
         self.assertGreater(len(train_data), 0)
-        print("OBM holdout data sample:")
-        print(holdout_data.head())
-        self.assertGreater(len(holdout_data), 0)
 
     #################################
     #      DEPLOYMENT SECTION       #
@@ -692,7 +688,7 @@ class TestOBMAndKB(unittest.TestCase):
     def test_30_delete_deployment(self):
         print("Delete current deployment: {}".format(self.service.deployment_id))
         self.service.delete()
-        self.wml_client.set.default_space(self.space_id) if is_cp4d() else None
+        self.wml_client.set.default_space(self.space_id) if not self.wml_client.default_space_id else None
         self.wml_client.repository.delete(self.service.asset_id)
         self.wml_client.set.default_project(self.project_id) if is_cp4d() else None
 
@@ -736,16 +732,13 @@ class TestOBMAndKB(unittest.TestCase):
 
     @print_test_separators
     def test_33_download_preprocessed_obm_training_data_notebook(self):
-        print("Downloading OBM preprocessed training data with holdout split...")
-        TestOBMAndKB.train_data, TestOBMAndKB.holdout_data = (
-            self.local_optimizer_cos.get_preprocessed_data_connection().read(with_holdout_split=True))
+        print("Downloading OBM preprocessed training data...")
+        TestOBMAndKB.train_data = (
+            self.local_optimizer_cos.get_preprocessed_data_connection().read())
 
         print("OBM train data sample:")
         print(self.train_data.head())
         self.assertGreater(len(self.train_data), 0)
-        print("OBM holdout data sample:")
-        print(self.holdout_data.head())
-        self.assertGreater(len(self.holdout_data), 0)
 
     # @print_test_separators
     # def test_34_visualize_obm_pipeline_notebook(self):
@@ -820,10 +813,9 @@ class TestOBMAndKB(unittest.TestCase):
     def test_39_delete_deployment_notebook(self):
         print("Delete current deployment: {}".format(self.service.deployment_id))
         self.service.delete()
-        self.wml_client.set.default_space(self.space_id) if is_cp4d() else None
+        self.wml_client.set.default_space(self.space_id) if not self.wml_client.default_space_id else None
         self.wml_client.repository.delete(self.service.asset_id)
         self.wml_client.set.default_project(self.project_id) if is_cp4d() else None
 
-
 if __name__ == '__main__':
     unittest.main()
