@@ -238,7 +238,7 @@ class Training(WMLResource):
                     **return type**: dict\n
 
             **Examples**
-                    **Example meta_props for Training run creation in Cloud Pack for Data version 3.1.0 or above:
+                    **Example meta_props for Training run creation in IBM Cloud Pak® for Data for Data version 3.0.1 or above:
                     >>> metadata = {
                     >>>  client.training.ConfigurationMetaNames.NAME: 'Hand-written Digit Recognition',
                     >>>  client.training.ConfigurationMetaNames.DESCRIPTION: 'Hand-written Digit Recognition Training',
@@ -325,6 +325,7 @@ class Training(WMLResource):
 
         """
 
+        WMLResource._chk_and_block_create_update_for_python36(self)
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
         Training._validate_type(meta_props, 'meta_props', object, True)
@@ -576,7 +577,7 @@ class Training(WMLResource):
            .. note::
 
                 This method prints the training logs.
-                This method is not supported for IBM Cloud Pack for Data.
+                This method is not supported for IBM Cloud Pak® for Data.
 
            **Example**
 
@@ -585,7 +586,7 @@ class Training(WMLResource):
         """
         ##For CP4D, check if either spce or project ID is set
         if self._client.ICP_30 or self._client.ICP_PLATFORM_SPACES:
-            raise WMLClientError("This method is not supported for IBM Cloud Pack for Data. " )
+            raise WMLClientError("This method is not supported for IBM Cloud Pak® for Data. " )
 
         self._client._check_if_either_is_set()
         details = self.get_details(training_uid)
@@ -831,7 +832,7 @@ class Training(WMLResource):
             .. note::
 
                 This method prints the training logs.
-                This method is not supported for IBM Cloud Pack for Data.
+                This method is not supported for IBM Cloud Pak® for Data.
 
             **Example**
 
@@ -840,7 +841,7 @@ class Training(WMLResource):
         """
 
         if self._client.ICP_30 or self._client.ICP_PLATFORM_SPACES:
-            raise WMLClientError("Metrics logs are not supported. This method is not supported for IBM Cloud Pack for Data. ")
+            raise WMLClientError("Metrics logs are not supported. This method is not supported for IBM Cloud Pak® for Data. ")
 
         training_uid = str_type_conv(training_uid)
         Training._validate_type(training_uid, u'training_uid', STR_TYPE, True)
@@ -927,14 +928,14 @@ class Training(WMLResource):
             .. note::
 
                 This method prints the training metrics.
-                This method is not supported for IBM Cloud Pack for Data.
+                This method is not supported for IBM Cloud Pak® for Data.
 
             **Example**
 
              >>> client.training.monitor_metrics(training_uid)
         """
         if self._client.ICP_30 or self._client.ICP_PLATFORM_SPACES:
-            raise WMLClientError("Metrics monitoring is not supported for IBM Cloud Pack for Data")
+            raise WMLClientError("Metrics monitoring is not supported for IBM Cloud Pak® for Data")
 
         training_uid = str_type_conv(training_uid)
         Training._validate_type(training_uid, u'training_uid', STR_TYPE, True)
