@@ -749,42 +749,38 @@ def remove_file(filename: str):
 
 
 class ProgressGenerator:
-    def __init__(self, number_of_estimators):
+    def __init__(self):
         self.progress_messages = {
-            ":::Pipeline node automl started": 1,
-            ":::Node automl: Scheduling job": 1,
-            ":::Node automl: Starting AutoAI on WML": 1,
-            "pre_hpo_d_output:::Node automl: AutoAI model computed": number_of_estimators,
-            "hpo_d_running_input:before_pipeline_execution::Node automl: AutoAI model computed": 40*number_of_estimators,
-            "hpo_c_running_input:before_pipeline_execution::Node automl: AutoAI model computed": 100*number_of_estimators,
-            ":::Node automl: Started daub_running stage": 1,
-            ":::Node automl: Started hpo_d stage": 1,
-            "hpo_d_output:::Node automl: AutoAI model computed": 1,
-            "cognito_output:::Node automl: AutoAI model computed": 1,
-            ":::Node automl: Completed feature_importance_pipeline stage": 1,
-            ":::Node automl: Found best data transformation chain and done HPO": 1,
-            "hpo_c_output:::Node automl: AutoAI model computed": 1,
-            ":::Node automl: Completed training of Full_dataset": 1,
-            ":::Node automl: Finished pipeline composition": 1,
-            ":::Pipeline node automl terminated": 1,
-            ":::Training job": 1
+            "pre_hpo_d_output": 15,
+            "hpo_d_output": 30,
+            "cognito_output": 50,
+            "hpo_c_output": 70,
+            "compose_model_type_output": 80,
+            "fold_output": 90,
+            "global_output": 99
         }
-        self.total = sum(self.progress_messages.values())
-        self.progress_bar_size_factor = 1
+        self.total = 100
         self.position = 0
+        self.max_position = 5
 
     def get_progress(self, text):
-        if self.position + 1 >= self.total:
-            return 0
-
         for i, e in enumerate(self.progress_messages):
             if e in text:
-                self.position += 1
-                return self.progress_bar_size_factor
-        return 0
+                pos = self.max_position
+                self.max_position = max(self.max_position, self.progress_messages[e])
+                if pos < self.max_position:
+                    progress = pos - self.position
+                    self.position = pos
+                    return progress
+
+        if self.position + 1 >= self.max_position:
+            return 0
+        else:
+            self.position += 1
+            return 1
 
     def get_total(self):
-        return self.progress_bar_size_factor * self.total
+        return self.total
 
 
 def is_ipython():
