@@ -386,6 +386,7 @@ def prepare_config_auto_ml(wml_pipeline_config: Dict,
     compute_plan = spec.lower()
     holdout_param = parameters['optimization']['holdout_param']
     daub_include_only_estimators = parameters['optimization']['daub_include_only_estimators']
+    cognito_transform_names = parameters['optimization']['cognito_transform_names']
     max_num_daub_ensembles = int(parameters['optimization']['max_num_daub_ensembles'])
     distinct_values = training_details['entity']['status'].get(
         'metrics', [{'context': {'classes': []}}])[0]['context']['classes']
@@ -431,6 +432,7 @@ def prepare_config_auto_ml(wml_pipeline_config: Dict,
                     "compute_plan": compute_plan,
                     "holdout_param": holdout_param,
                     "daub_include_only_estimators": daub_include_only_estimators,
+                    "cognito_transform_names": cognito_transform_names,
                     "max_num_daub_ensembles": max_num_daub_ensembles
                 }
             },
